@@ -1,11 +1,12 @@
 package Games::Mastermind;
+{
+  $Games::Mastermind::VERSION = '0.04';
+}
 
 use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.03';
-
 sub new {
     my $class = shift;
     my $self  = bless {
@@ -62,7 +63,7 @@ sub play {
     # white marks
     @guess = sort grep defined, @guess;
     @code  = sort grep defined, @code;
-    while( @guess && @code ) { 
+    while( @guess && @code ) {
         if( $guess[0] eq $code[0] ) {
             $marks->[1]++;
             shift @guess;
@@ -82,11 +83,19 @@ sub play {
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding iso-8859-1
 
 =head1 NAME
 
-Games::Mastermind - A simple framework for MasterMind games
+Games::Mastermind - A simple framework for Mastermind games
+
+=head1 VERSION
+
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -135,7 +144,7 @@ Give the answer to C<@guess> as a reference to an array of two numbers:
 the number of black marks (right colour in the right position) and
 the number of white marks (right colour in the wrong position).
 
-The winning combination is C<[ $mm->holes(), 0 ]>.
+The winning combination is C<< [ $mm->holes(), 0 ] >>.
 
 =item reset()
 
@@ -163,7 +172,7 @@ The number of holes.
 
 =item history()
 
-Return a reference to the game history, as an array of [ guess, answer ]
+Return a reference to the game history, as an array of C<[ guess, answer ]>
 arrays.
 
 =item code()
@@ -185,7 +194,7 @@ and returns the outcome of this turn.
 This example script show a very dumb player program:
 
     use Games::Mastermind;
-    
+
     my $game  = Games::Mastermind->new();    # standard game
     my $holes = $game->holes();
     my @pegs  = @{ $game->pegs() };
@@ -202,10 +211,6 @@ The flow of control is in the hand of the player program or object,
 which asks the game if the guess was good. The count of turns must
 be handled by the controlling program.
 
-=head1 AUTHOR
-
-Philippe "BooK" Bruhat, C<< <book@cpan.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -219,12 +224,33 @@ your bug as I make changes.
 Sbastien Aperghis-Tramoni opened his old Super Mastermind game to
 check out what the black markers meant.
 
-=head1 COPYRIGHT & LICENSE
+=head1 BUGS
 
-Copyright 2005-2006 Philippe "BooK" Bruhat, All Rights Reserved.
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Mastermind or by email to
+bug-games-mastermind@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright 2005-2013 Philippe Bruhat (BooK), All Rights Reserved.
+
+=head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
+
+__END__
+
+# ABSTRACT: A simple framework for Mastermind games
+
